===============
Satel Integra 2
===============


.. image:: https://img.shields.io/pypi/v/satel_integra2.svg
        :target: https://pypi.python.org/pypi/satel_integra2

.. image:: https://img.shields.io/pypi/pyversions/satel_integra2.svg
        :target: https://pypi.org/project/satel_integra2/

.. image:: https://readthedocs.org/projects/satel-integra2/badge/?version=latest
        :target: https://satel-integra2.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://github.com/wasilukm/satel_integra2/actions/workflows/dev.yml/badge.svg
        :target: https://github.com/wasilukm/satel_integra2/actions/workflows/dev.yml

.. image:: https://codecov.io/gh/wasilukm/satel_integra2/branch/main/graphs/badge.svg
        :target: https://codecov.io/github/wasilukm/satel_integra2

Communication library and basic testing tool for Satel Integra alarm system. Communication via tcpip protocol published by SATEL.

This is a fork of https://github.com/c-soft/satel_integra.


* Free software: MIT license
* Documentation: https://satel-integra2.readthedocs.io.


Features
--------

* all the features from the original `satel_integra` library in version 0.3.7
* encrypted communication

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

